@@ -40,7 +40,7 @@ our @EXPORT_OK = qw(
     git_ignore
     git_release
     git_repo
-    git_status
+    git_status_differs
     git_tag
     init
     make_dist
@@ -63,7 +63,7 @@ our %EXPORT_TAGS = (
     private => _export_private(),
 );
 
-our $VERSION = '1.01';
+our $VERSION = '1.03';
 
 use constant {
     GITHUB_CI_FILE      => 'github_ci_default.yml',
@@ -237,6 +237,10 @@ sub cpan_upload {
         croak("\ncpan_upload() requires the CPAN_USERNAME and CPAN_PASSWORD env vars set");
     }
 
+    if ($args{dry_run}) {
+        print "\nCPAN upload is in dry run mode... nothing will be uploaded\n";
+    }
+
     CPAN::Uploader->upload_file(
         $dist_file_name,
         \%args
@@ -276,8 +280,8 @@ sub git_release {
 sub git_repo {
     _git_repo();
 }
-sub git_status {
-    _git_status(@_);
+sub git_status_differs {
+    _git_status_differs(@_);
 }
 sub git_tag {
     _git_tag(@_);
@@ -472,6 +476,8 @@ sub version_bump {
         $dry_run = 1;
     }
 
+    $fs_entry //= DEFAULT_DIR;
+
     _validate_version($version);
     _validate_fs_entry($fs_entry);
 
@@ -544,6 +550,8 @@ sub version_incr {
 sub version_info {
     my ($fs_entry) = @_;
 
+    $fs_entry //= DEFAULT_DIR;
+
     _validate_fs_entry($fs_entry);
 
     my @module_files = _module_find_files($fs_entry);
