@@ -29,14 +29,14 @@ our @EXPORT_OK = qw(
     _git_pull
     _git_release
     _git_repo
-    _git_status
+    _git_status_differs
     _git_tag
 );
 our %EXPORT_TAGS = (
     all     => [@EXPORT_OK],
 );
 
-our $VERSION = '1.01';
+our $VERSION = '1.03';
 
 my $spinner_count;
 
@@ -116,10 +116,10 @@ sub _git_clone {
     return $?;
 }
 sub _git_pull {
-    my ($version) = @_;
+    my ($verbose) = @_;
 
     if (_validate_git()) {
-        `git pull`;
+        _exec('git pull', $verbose);
         croak("Git pull failed with exit code: $?") if $? != 0;
     }
     else {
@@ -150,8 +150,8 @@ sub _git_release {
     $wait_for_ci //= 1;
     my $verbose = 0;
 
-    if (! _git_status()) {
-        _git_pull(0);
+    if (_git_status_differs()) {
+        _git_pull();
         _git_commit($version, $verbose);
         _git_push($verbose);
     }
@@ -184,6 +184,8 @@ sub _git_release {
             return 0;
         }
     }
+
+    return 1;
 }
 sub _git_repo {
     my $repo;
@@ -202,7 +204,7 @@ sub _git_repo {
         return $?;
     }
 }
-sub _git_status {
+sub _git_status_differs {
     my $status_output;
 
     if (_validate_git()) {
@@ -221,10 +223,10 @@ sub _git_status {
     my @status = split /\n/, $status_output;
 
     for (0..$#status) {
-        return 0 if $status[$_] !~ /$git_output[$_]/;
+        return 1 if $status[$_] !~ /$git_output[$_]/;
     }
 
-    return 1;
+    return 0;
 }
 sub _git_tag {
     my ($version, $verbose) = @_;
