@@ -47,7 +47,7 @@ our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
 my $orig_dir        = 't/data/orig';
 my $work_dir        = 't/data/work';
-my $tpl_dir         = 't/data/module_template';
+my $tpl_dir         = 't/data/template/module_template';
 my $unwanted_dir    = 't/data/work/unwanted';
 my $init_dir        = 't/data/work/init';
 my $ci_dir          = 't/data/work/ci';
@@ -226,6 +226,17 @@ sub trap_warn {
     }
 }
 
+sub make_second_module {
+    my ($dest) = @_;
+
+    if (! -e $dest) {
+        mkdir $dest or die "Can't create $dest dir\n";
+        is -d $dest, 1, "$dest dir created ok";
+    }
+
+    copy 't/data/orig/One.pm', $dest or die "Can't copy One.pm to $dest\n";
+
+}
 sub module_args {
     my %module_args = (
         author  => 'Test Author',
